#! /usr/bin/python3


import sys
import numpy
from   matplotlib import pyplot as plt
import matplotlib
matplotlib.use('Agg')
"""
https://stackoverflow.com/questions/45993879/matplot-lib-fatal-io-error-25-inappropriate-ioctl-for-device-on-x-server-loc
by Jiri Mares
"""



def plot_me(xyScatter = None, xyLine = None, title = "_" , fileName = None,xl = "Glucose [M]", yl = "relax time [s]",
        invertX = False, fadeAlongData = False , xlog = False, ylog=False, xlim = None, ylim = None, square=False,
        dotsize = 7):

    if fileName is None:
        fileName = str(title)

    matplotlib.rcParams.update({'font.size': 10})
    #plt.figure()
    fig, ax = plt.subplots()
    if xyLine is not None:
        plt.plot(xyLine[:,0], xyLine[:,1], 'k', lw=1, zorder=9, label = '_nolegend_')

    if ylog:
        plt.yscale('log')
    if xlog:
        plt.xscale('log')

    plt.xlabel( xl )
    plt.ylabel( yl )
    plt.title(str(title))


    if xyScatter is not None:
        if fadeAlongData: # actually "upfade"
            alpha = numpy.linspace(0.3, 1, len(xyScatter))
            for i in range(0, len(xyScatter)):
                plt.scatter(xyScatter[i,0], xyScatter[i,1], c='b', s=7, alpha = alpha[i] ,zorder=10, linewidths=0.5 , edgecolors=(0, 0, 0)) #linewidth of he edge
            plt.scatter(xyScatter[-1,0], xyScatter[-1,1], c='r', s=14, alpha = 1.0,  zorder=10, edgecolors=(0, 0, 0)) #the final one in red
        
        
        else:
            plt.scatter(xyScatter[:,0], xyScatter[:,1], c='b', s=dotsize, zorder=10, linewidths=0.2,  alpha = 0.5,edgecolors=(0, 0, 0))


    if xlim is not None:
        ax.set_xlim(xlim[0], xlim[1])
    if ylim is not None:
        ax.set_ylim(ylim[0], ylim[1])
    if invertX:
        ax.invert_xaxis()

    if square:
        fig.set_figwidth(6.5)
        fig.set_figheight(6.5)

    plt.savefig(fileName + ".pdf", dpi = 600)
    plt.close("all")


if __name__ == "__main__":
    nPoints = 10
    xy = numpy.zeros((nPoints, 2) , float)
    x=numpy.linspace(0,10,nPoints)
    y=numpy.linspace(100,1000,10)
    xy[:,0] = x[:]
    xy[:,1] = y[:]


    ticks =  numpy.logspace(2,3,50)
    wanted = numpy.array([8,14,26,38])
    tw = ticks[wanted]
    print(tw)

    x = numpy.array([4,10,20,30], float) + 273.15
    y = tw
    xy = numpy.zeros((4, 2) , float)
    xy[:,0] = x[:]
    xy[:,1] = y[:]

